xclim.indicators package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xclim.indicators.atmos
   xclim.indicators.land
   xclim.indicators.seaIce

Module contents
---------------

.. automodule:: xclim.indicators
   :members:
   :undoc-members:
   :show-inheritance:
